var indexSectionsWithContent =
{
  0: "abcdefhilnorstuw",
  1: "be",
  2: "bdehrtu",
  3: "bel",
  4: "acfilnosuw",
  5: "be",
  6: "be",
  7: "be",
  8: "bdehilo",
  9: "abcdefhilnorstu"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Pages"
};

